#include <iostream>
#include <iomanip>
#include <fstream>
#include <vector>
#include <array>
#include <algorithm>
#include <utility>
#include <map>
#include <queue>
#include <set>
#include <cmath>
#include <cstdio>
#include <cstring>
#include <functional>
#include <numeric>
#include <list>
#include <ios>
#include <bitset>
#include <string>
#include <sstream>

struct Triangle
{
    int64_t sql[3];
};

int64_t sixteenSquaredArea(Triangle t)
{
    int64_t a = t.sql[0];
    int64_t b = t.sql[1];
    int64_t c = t.sql[2];
    return 4LL * a * b - (a + b - c) * (a + b - c);
}

bool formsRightAngle(Triangle t1, Triangle t2)
{
    int64_t a = t1.sql[0];
    int64_t b = t1.sql[1];
    int64_t c = t1.sql[2];
    int64_t A = t2.sql[0];
    int64_t B = t2.sql[1];
    int64_t C = t2.sql[2];
    if (b != C)
        return false;
    int64_t term1 = c - a - b;
    int64_t term2 = B - A - C;
    if (term1 >= 0 || term2 >= 0)
        return false;
    return term1 * term2 == std::sqrt(sixteenSquaredArea(t1)) * std::sqrt(sixteenSquaredArea(t2));
}

bool formsStraightAngle(Triangle t1, Triangle t2)
{
    int64_t a = t1.sql[0];
    int64_t b = t1.sql[1];
    int64_t c = t1.sql[2];
    int64_t A = t2.sql[0];
    int64_t B = t2.sql[1];
    int64_t C = t2.sql[2];
    if (b != C)
        return false;
    int64_t term1 = c - a - b;
    int64_t term2 = B - A - C;
    if (term1 * term2 > 0)
        return false;
    // Can overflow
    // return a * term2 * term2 == A * term1 * term1;
    // Workaround hack: we know that if a and A are two sides of a straight angle that sqrt(aA) must be an integer. 
    int64_t rtaA = std::sqrt(a * A);
    if (rtaA * rtaA != a * A)
        return false;
    return rtaA * std::abs(term2) == A * std::abs(term1);
}

int64_t sumSquaredSides(int64_t a, int64_t b)
{
    int64_t rtab = std::sqrt(a*b);
    if (rtab * rtab != a*b)
        return 0;
    return a + b + 2LL * rtab;
}

bool checkCaseI(int64_t sqSide, std::vector<Triangle> tris)
{
    for (int i = 0; i < 4; i++)
    {
        if (tris[i].sql[0] != sqSide)
            return false;
        int nexti = (i + 1) % 4;
        if (!formsRightAngle(tris[i], tris[nexti]))
            return false;
    }
    return true;
}

bool checkCaseII(int64_t sqSide, std::vector<Triangle> tris)
{
    for (int i = 0; i < 3; i++)
    {
        if (tris[i].sql[0] + tris[i].sql[1] != tris[i].sql[2])
            return false;
        if (tris[i].sql[2] != tris[3].sql[i])
            return false;
    }
    if (tris[0].sql[0] != sqSide)
        return false;
    if (sumSquaredSides(tris[0].sql[1], tris[1].sql[0]) != sqSide)
        return false;
    if (sumSquaredSides(tris[1].sql[1], tris[2].sql[0]) != sqSide)
        return false;
    if (tris[2].sql[1] != sqSide)
        return false;
    return true;
}

bool checkCaseVI(int64_t sqSide, std::vector<Triangle> tris)
{
    if (!formsRightAngle(tris[0], tris[1]))
        return false;
    if (!formsRightAngle(tris[2], tris[3]))
        return false;
    if (tris[0].sql[0] + tris[0].sql[2] != tris[0].sql[1])
        return false;
    if (tris[2].sql[0] + tris[2].sql[2] != tris[2].sql[1])
        return false;
    if (tris[0].sql[0] != sqSide || tris[2].sql[0] != sqSide)
        return false;
    if (sumSquaredSides(tris[1].sql[0], tris[2].sql[2]) != sqSide)
        return false;
    if (sumSquaredSides(tris[3].sql[0], tris[0].sql[2]) != sqSide)
        return false;
    return true;
}

std::vector<std::vector<int> > perms = { {0,1,2}, {0,2,1}, {1,0,2}, {1,2,0}, {2,0,1}, {2,1,0} };

bool anyOrientIsHalfSquare(int64_t sqSide, Triangle t)
{
    for (int i = 0; i < 3; i++)
    {
        int ip1 = (i + 1) % 3;
        int ip2 = (i + 2) % 3;
        if (t.sql[i] == 2LL * sqSide && t.sql[ip1] == sqSide && t.sql[ip2] == sqSide)
            return true;
    }
    return false;
}

bool checkCaseIVi(int64_t sqSide, std::vector<Triangle> tris)
{
    if (!formsRightAngle(tris[0], tris[1]))
        return false;
    if (tris[0].sql[0] != sqSide || tris[1].sql[0] != sqSide)
        return false;
    if (tris[2].sql[0] != 2LL * sqSide)
        return false;
    for (int i = 0; i < 3; i++)
    {
        int ip1 = (i + 1) % 3;
        if (tris[i].sql[1] != tris[ip1].sql[2])
            return false;
    }
    // it's safe to ignore checking that tris[2] has positive orientation since otherwise the total area of the square wouldn't add up
    return true;
}

bool checkCaseVII(int64_t sqSide, std::vector<Triangle> tris)
{
    if (!formsRightAngle(tris[1], tris[2]))
        return false;
    if (!formsRightAngle(tris[2], tris[3]))
        return false;
    if (tris[0].sql[0] + tris[0].sql[1] != tris[0].sql[2])
        return false;
    if (tris[0].sql[1] != sqSide || tris[1].sql[0] != sqSide || tris[2].sql[0] != sqSide)
        return false;
    if (sumSquaredSides(tris[3].sql[0], tris[0].sql[0]) != sqSide)
        return false;
    if (sumSquaredSides(tris[1].sql[2], tris[3].sql[1]) != tris[0].sql[2])
        return false;

    return true;
}

void allArrangement(std::vector<Triangle> tris, std::vector<std::vector<Triangle> >& options)
{
    int n = tris.size();
    std::vector<int> order;
    int nperms = perms.size();
    int combos = 1;
    for (int i = 0; i < n; i++)
    {
        order.push_back(i);
        combos *= nperms;
    }

    do
    {
        for (int p = 0; p < combos; p++)
        {
            std::vector<int> ps(n);
            int tmp = p;
            for (int i = 0; i < n; i++)
            {
                ps[i] = tmp % nperms;
                tmp /= nperms;
            }

            std::vector<Triangle> option(n);
            for (int i = 0; i < n; i++)
            {
                for (int j = 0; j < 3; j++)
                {
                    option[i].sql[j] = tris[order[i]].sql[perms[ps[i]][j]];
                }
            }
            options.push_back(option);
        }
    } while (std::next_permutation(order.begin(), order.end()));
}

void mergeAll(int64_t sqSide, std::vector<Triangle> triangles, std::vector<Triangle> &results)
{
    int n = triangles.size();
    if (n == 1)
    {
        results.push_back(triangles[0]);
        return;
    }
    for (int i = 0; i < n; i++)
    {
        for (int j = i + 1; j < n; j++)
        {
            std::vector<Triangle> toFuse = { triangles[i], triangles[j] };
            std::vector<std::vector<Triangle> > toFuseArrangements;
            allArrangement(toFuse, toFuseArrangements);
            for (auto& triPair : toFuseArrangements)
            {
                if (formsStraightAngle(triPair[0], triPair[1]))
                {
                    Triangle fused;
                    // cannot have irrational side lengths
                    int64_t sumlen = sumSquaredSides(triPair[0].sql[0], triPair[1].sql[0]);
                    if (sumlen && sumlen <= 2LL * sqSide)
                    {
                        fused.sql[0] = sumlen;
                        fused.sql[1] = triPair[1].sql[1];
                        fused.sql[2] = triPair[0].sql[2];
                        std::vector<Triangle> leftovers = { fused };
                        for (int k = 0; k < n; k++)
                        {
                            if (k != i && k != j)
                                leftovers.push_back(triangles[k]);
                        }
                        mergeAll(sqSide, leftovers, results);
                    }
                }
            }
        }
    }
}

bool checkCaseIII(int64_t sqSide, std::vector<Triangle> tris)
{
    if (!formsRightAngle(tris[0], tris[1]) || !formsRightAngle(tris[2], tris[0]))
        return false;
    for (int i = 0; i < 3; i++)
    {
        if (tris[i].sql[0] != sqSide)
            return false;
    }    
    if (sumSquaredSides(tris[1].sql[1], tris[2].sql[2]) != sqSide)
        return false;
    return true;
}

bool doCase()
{
    std::vector<Triangle> tris(4);
    for (int i = 0; i < 4; i++)
        for (int j = 0; j < 3; j++)
            std::cin >> tris[i].sql[j];

    int64_t totalArea = 0;
    for (int i = 0; i < 4; i++)
    {
        int64_t sqArea = sixteenSquaredArea(tris[i]);
        int64_t area = std::sqrt(sqArea);
        if (area * area != sqArea)
            return false;
        totalArea += area;
    }
    if (totalArea % 4LL)
    {
        return false;
    }
    int64_t sqSide = totalArea / 4LL;
    
    std::vector<std::vector<Triangle> > fourArrangements;
    allArrangement(tris, fourArrangements);
    for (auto& fourTris : fourArrangements)
    {
        // one-off cases involving all four triangles
        if (checkCaseI(sqSide, fourTris))
            return true;
        if (checkCaseII(sqSide, fourTris))
            return true;
        if (checkCaseVI(sqSide, fourTris))
            return true;
        if (checkCaseVII(sqSide, fourTris))
            return true;
    }

    for (int i = 0; i < 4; i++)
    {
        if (anyOrientIsHalfSquare(sqSide, tris[i]))
        {
            // case IV: half of the square
            std::vector<Triangle> leftovers;
            for (int k = 0; k < 4; k++)
            {
                if (k != i)
                    leftovers.push_back(tris[k]);
            }

            std::vector<std::vector<Triangle> > leftoverArrangements;
            allArrangement(leftovers, leftoverArrangements);

            for (auto& leftoverArrangement : leftoverArrangements)
            {
                if (checkCaseIVi(sqSide, leftoverArrangement))
                    return true;
            }

            // other cases
            std::vector<Triangle> fused;
            mergeAll(sqSide, leftovers, fused);
            for (auto t : fused)
            {
                if (anyOrientIsHalfSquare(sqSide, t))
                    return true;
            }
        }
    }

    for (int i = 0; i < 4; i++)
    {
        for (int j = i + 1; j < 4; j++)
        {
            std::vector<Triangle> tofuse;
            std::vector<Triangle> leftovers;
            for (int k = 0; k < 4; k++)
            {
                if (k == i || k == j)
                    tofuse.push_back(tris[k]);
                else
                    leftovers.push_back(tris[k]);
            }

            std::vector<Triangle> fused;
            mergeAll(sqSide, tofuse, fused);
            std::vector<Triangle> fused2;
            mergeAll(sqSide, leftovers, fused2);
            for (auto t1 : fused)
            {
                for (auto t2 : fused2)
                {
                    // case V
                    if (anyOrientIsHalfSquare(sqSide, t1) && anyOrientIsHalfSquare(sqSide, t2))
                        return true;
                }

                std::vector<Triangle> trio = leftovers;
                trio.push_back(t1);

                std::vector<std::vector<Triangle> > trioArrangements;
                allArrangement(trio, trioArrangements);

                for (auto& trioArrangement : trioArrangements)
                {
                    if (checkCaseIII(sqSide, trioArrangement))
                        return true;
                }
            }
        }
    }

    return false;
}

int main()
{
    int t;
    std::cin >> t;
    for (int i = 0; i < t; i++)
    {
        std::cout << (doCase() ? "1" : "0") << std::endl;
    }
}
