from fractions import Fraction
from math import gcd
import itertools

def sgn(x):
  return int(x>0)-int(x<0)

def exclude(l, idxtoexclude):
  return [x for i, x in enumerate(l) if i != idxtoexclude]

def exactsqrt(n):
  r = int(n**0.5)
  assert r*r <= n
  while r * r < n: r += 1
  if r * r != n: return None
  return r

def sumsqrtasqrtb(a, b):
  g = gcd(a, b)
  a //= g
  b //= g
  # a and b are relatively prime, if either of them is not a perfect square then it's bad
  aroot = exactsqrt(a)
  broot = exactsqrt(b)
  if aroot is None or broot is None: return None
  ans = (aroot+broot)*(aroot+broot)*g
  return ans

def areacheck(triangles):
  ret = 0
  for a, b, c in triangles:
    amt = (a+b+c)**2 - 2*(a**2 + b**2 + c**2)
    assert amt > 0, "not a triangle"
    p = exactsqrt(amt)
    if p is None: return None
    ret += Fraction(p, 4)
  if int(ret) != ret: return None
  return int(ret)

def checksqrtaplussqrtbissqrts(a, b, s):
  # check if sqrt(a) + sqrt(b) == sqrt(s)
  if s-a-b <= 0: return False
  return 4*a*b == (s-a-b)**2

def canmaketriangle(trianglea, triangleb, goaltriangle):
  # can you fuse trianglea and triangleb to make goaltriangle
  for i in range(3):
    for j in range(3):
      if trianglea[i] != triangleb[j]: continue
      sharedsidelength = trianglea[i]
      # combine these two
      # brute force sides aligned with triangle
      for a in range(3):
        if i == a: continue
        for b in range(3):
          if j == b: continue
          othera = 3-i-a
          x = trianglea[othera]
          otherb = 3-j-b
          y = triangleb[otherb]
          for ga in range(3):
            if trianglea[a] != goaltriangle[ga]: continue
            for gb in range(3):
              if ga == gb or triangleb[b] != goaltriangle[gb]: continue
              gc = 3-ga-gb
              while gc in [ga, gb]: gc += 1
              # check other sides sum to correct length
              if not checksqrtaplussqrtbissqrts(trianglea[othera], triangleb[otherb], goaltriangle[gc]): continue
              # check that sin of angles matches
              lhsn = sharedsidelength * x - (sharedsidelength + x - trianglea[a]) ** 2
              lhsd = sharedsidelength * x
              rhsn = sharedsidelength * y - (sharedsidelength + y - triangleb[b]) ** 2
              rhsd = sharedsidelength * y
              if Fraction(lhsn, lhsd) != Fraction(rhsn, rhsd): continue
              # check that cosines are opposite in sign
              if sgn(sharedsidelength+x-trianglea[a]) + sgn(sharedsidelength+y-triangleb[b]) == 0: return True
  return False

def fusetriangle(trianglea, triangleb):
  ret = []
  for i in range(3):
    for j in range(3):
      if trianglea[i] != triangleb[j]: continue
      for a in range(3):
        if a == i: continue
        for b in range(3):
          if b == j: continue
          ai = 3-i-a
          bj = 3-j-b
          cand = sumsqrtasqrtb(trianglea[ai], triangleb[bj])
          if cand is not None:
            tri = tuple(sorted([trianglea[a], triangleb[b], cand]))
            if not canmaketriangle(trianglea, triangleb, tri): continue
            ret.append(tri)
  return list(set(ret))

def case1(pairs, s):
  for mask in range(16):
    l = [(mask >> i) & 1 for i in range(4)]
    # for i, match pairs[i][0] with pairs[(i+1)%4][l[i]]
    good = True
    other = 0
    for i in range(4):
      if pairs[i][other] != pairs[(i+1)%4][l[(i+1)%4]]:
        good = False
        break
      a = pairs[i][other]
      b = pairs[i][1-other]
      c = pairs[(i+1)%4][1-l[(i+1)%4]]
      if a+s-b < 0 or a+s-c < 0:
        good = False
        break
      if ((b-a-s)*(c-a-s))**2 != (4*a*s-(a+s-b)**2)*(4*a*s-(a+s-c)**2):
        good = False
        break
      other = 1-l[(i+1)%4]
    if good: return True
  return False

def case2(pairs, s):
  for i in [1, 2]:
    pairs[i].sort()
    if pairs[i].pop() != s: return False
  if checksqrtaplussqrtbissqrts(pairs[0][0], pairs[1][0], s) and checksqrtaplussqrtbissqrts(pairs[0][1], pairs[2][0], s): return True
  if checksqrtaplussqrtbissqrts(pairs[0][1], pairs[1][0], s) and checksqrtaplussqrtbissqrts(pairs[0][0], pairs[2][0], s): return True
  return False

def checktripletriangle(trianglea, triangleb, trianglec, s):
  if 2*s not in trianglea or s not in triangleb or s not in trianglec: return False
  ta = [x for x in trianglea]
  ta.remove(2*s)
  tb = [x for x in triangleb]
  tb.remove(s)
  tc = [x for x in trianglec]
  tc.remove(s)
  if ta[0] == tb[0] and tb[1] == tc[0] and tc[1] == ta[1]: return True
  if ta[0] == tb[0] and tb[1] == tc[1] and tc[0] == ta[1]: return True
  if ta[0] == tb[1] and tb[0] == tc[0] and tc[1] == ta[1]: return True
  if ta[0] == tb[1] and tb[0] == tc[1] and tc[0] == ta[1]: return True
  return False

def gentrapezoid(trianglea, triangleb, s):
  if s not in trianglea: return []
  ta = [x for x in trianglea]
  ta.remove(s)
  ta.sort()
  if ta[1] not in triangleb: return []
  tb = [x for x in triangleb]
  tb.remove(ta[1])
  tb.sort()
  trapezoids = []
  for (x, y) in itertools.permutations(tb):
    # TODO: check angle
    trapezoids.append((ta[0], x, y))
  return trapezoids

def checkinvertedtrapezoid(triangles, s):
  ta = [x for x in triangles[0]]
  ta.remove(s)
  ta.sort()
  hypo = ta[1]
  if s not in triangles[1]: return False
  tb = [x for x in triangles[1]]
  tb.remove(s)
  for (blhs, brhs) in itertools.permutations(tb):
    tc = [x for x in triangles[2]]
    if blhs not in tc: continue
    tc.remove(blhs)
    for (clhs, crhs) in itertools.permutations(tc):
      if not checksqrtaplussqrtbissqrts(clhs, ta[0], s): continue
      td = [x for x in triangles[3]]
      if brhs not in td: continue
      td.remove(brhs)
      for (dlhs, drhs) in itertools.permutations(td):
        if drhs != s: continue
        if checksqrtaplussqrtbissqrts(crhs, dlhs, hypo): return True
  return False

def checktripleroot(rootcand, lhstri, rhstri, s):
  rootcand.remove(s)
  for (lhsh, rhsh) in itertools.permutations(rootcand):
    if sorted(lhstri) == sorted([s, lhsh, lhsh-s]) and sorted(rhstri) == sorted([s, rhsh, rhsh-s]): return True
  return False

def makerectangle(a, b):
  if sorted(a) != sorted(b): return None
  return min(a)

def check(triangles, s):
  # sqrt(sidelength) is the length of the square
  # NOTE: because we check all permutations, we can assign the order explicitly
  # case 1: all four triangles intersect at a common interior point
  matchcnt = sum([s in t for t in triangles])
  if matchcnt == 4:
    pairs = []
    for a, b, c in triangles:
      if a == s: pairs.append((b, c))
      elif b == s: pairs.append((a, c))
      elif c == s: pairs.append((a, b))
      else: assert False
    if case1(pairs, s): return True
  # case 2: a triangle is inscribed inside
  for a in range(3):
    for b in range(3):
      for c in range(3):
        if sorted(triangles[3]) != sorted([triangles[0][a], triangles[1][b], triangles[2][c]]): continue
        pairs = []
        pairs.append(exclude(triangles[0], a))
        pairs.append(exclude(triangles[1], b))
        pairs.append(exclude(triangles[2], c))
        if case2(pairs, s): return True
  # case 3: it's two rectangles
  if matchcnt == 4:
    for j in range(1, 3):
      a = 1
      while a == j: a += 1
      b = 3
      while b == j: b -= 1
      alhs = makerectangle(triangles[0], triangles[j])
      blhs = makerectangle(triangles[a], triangles[b])
      if alhs is not None and blhs is not None and checksqrtaplussqrtbissqrts(alhs, blhs, s): return True
  # case 4:
  # triangle 0 takes one side and crosses the square
  # triangle 1 takes one corner
  # triangles 2 and 3 take the other corner
  roottriangle = [x for x in triangles[0]]
  if min(roottriangle) == s:
    roottriangle.sort()
    for other in roottriangle[1:]:
      if sorted(triangles[1]) != sorted([s, other, other - s]): continue
      othertriangle = [s, roottriangle[1] + roottriangle[2] - other]
      othertriangle.append(othertriangle[1] - othertriangle[0])
      if canmaketriangle(triangles[2], triangles[3], othertriangle): return True
  # case 5:
  # triangle 0 takes the corner 
  # fuse the other three to make triangle 0
  if sorted(triangles[0]) == [s, s, 2*s]:
    for tri in fusetriangle(triangles[1], triangles[2]):
      for tri2 in fusetriangle(triangles[3], tri):
        # print(triangles[1], triangles[2], tri, triangles[3], tri2)
        if tri2 == (s, s, 2*s): return True
  # case 6:
  # triangles 0 and 1 merge to form a corner
  # triangles 2 and 3 merge to form the other corner
  if (s, s, 2*s) in fusetriangle(triangles[0], triangles[1]) and (s, s, 2*s) in fusetriangle(triangles[2], triangles[3]): return True
  # case 7:
  # triangle 0 is a corner, other three triangles have a shared interior point
  if sorted(triangles[0]) == [s, s, 2*s]:
    if checktripletriangle(triangles[1], triangles[2], triangles[3], s): return True
  # case 8:
  # two trapezoids are formed
  atrapezoids = gentrapezoid(triangles[0], triangles[1], s)
  btrapezoids = gentrapezoid(triangles[2], triangles[3], s)
  for (al, ar, ax) in atrapezoids:
    for (bl, br, bx) in btrapezoids:
      if ax != bx: continue
      if checksqrtaplussqrtbissqrts(al, bl, s) and checksqrtaplussqrtbissqrts(ar, br, s): return True
      if checksqrtaplussqrtbissqrts(al, br, s) and checksqrtaplussqrtbissqrts(ar, bl, s): return True
  # case 9:
  # triangle 0 takes bottom left corner
  # triangle 1 takes the other corner and shared side
  # triangle 2 is top left, triangle 3 is bottom right
  if s in triangles[0] and max(triangles[0]) > s:
    if checkinvertedtrapezoid(triangles, s): return True
  # case 10
  # case 4, but combine to form the root triangle
  # triangles 0 and 1 form the root triangle
  # triangle 2 goes to the left, triangle 3 goes to the right
  for tri in fusetriangle(triangles[0], triangles[1]):
    if s in tri:
      if checktripleroot(list(tri), triangles[2], triangles[3], s): return True
  # no other cases
  return False

def solve():
  triangles = []
  for _ in range(4): triangles.append(sorted([int(x) for x in input().split()]))
  squarearea = areacheck(triangles)
  # print(squarearea, "square area")
  if squarearea is None: return 0
  for p in itertools.permutations(triangles):
    if check(p, squarearea):
      return 1
  return 0

for _ in range(int(input())): print(solve())
